@@ -2,14 +2,15 @@
 Implements an Entry that looks up pre-tabulated Gibbs free energies from the NIST-JANAF
 tables.
 """
-from typing import Dict, Optional
+from typing import Dict, Optional, List
 
 from pymatgen.core.composition import Composition
+from pymatgen.entries.computed_entries import EnergyAdjustment
 
 from rxn_network.data import PATH_TO_NIST, load_experimental_data
 from rxn_network.entries.experimental import ExperimentalReferenceEntry
 
-G_COMPOUNDS = load_experimental_data(PATH_TO_NIST / "compounds.json")
+G_COMPOUNDS = load_experimental_data(PATH_TO_NIST / "compounds.json.gz")
 
 
 class NISTReferenceEntry(ExperimentalReferenceEntry):
@@ -27,7 +28,11 @@ class NISTReferenceEntry(ExperimentalReferenceEntry):
     REFERENCES = G_COMPOUNDS
 
     def __init__(
-        self, composition: Composition, temperature: float, data: Optional[Dict] = None
+        self,
+        composition: Composition,
+        temperature: float,
+        energy_adjustments: Optional[List[EnergyAdjustment]] = None,
+        data: Optional[Dict] = None,
     ):
         """
         Args:
@@ -37,4 +42,9 @@ class NISTReferenceEntry(ExperimentalReferenceEntry):
                 interpolated. Defaults to 300 K.
             data: Optional dictionary containing entry data
         """
-        super().__init__(composition, temperature, data)
+        super().__init__(
+            composition=composition,
+            temperature=temperature,
+            energy_adjustments=energy_adjustments,
+            data=data,
+        )
